import lz4.frame

from .zip import Zip


class LZ4(Zip):
    def __init__(self, compresslevel: float):
        compresslevel = int(max(0, round(compresslevel * 32 - 16)))
        super().__init__(lz4.frame, compresslevel)



from typing import *
import os, sys, io, time, random, traceback, json

import numpy as np
import pickle as msgpack

from .base import Base

class Zip(Base):
    def __init__(self, compressor, compresslevel: int):
        self._compressor = compressor
        self._compresslevel = compresslevel

    def encode(self, array: np.ndarray) -> bytes:
        info = {
            'shape': array.shape,
            'dtype': str(array.dtype),
            'data': self._compressor.compress(array.tobytes(), self._compresslevel),
        }
        return msgpack.dumps(info)
    
    def decode(self, content: bytes) -> np.ndarray:
        info = msgpack.loads(content)
        data = self._compressor.decompress(info['data'])
        return np.frombuffer(bytearray(data), dtype=info['dtype'])\
                                            .reshape(info['shape'])

    


import os
from setuptools import find_packages, setup

project = "hub"
version = "0.9.0.1"

this_directory = os.path.abspath(os.path.dirname(__file__))
with open(os.path.join(this_directory, "README.md")) as f:
    long_description = f.read()

with open(os.path.join(this_directory, "requirements.txt"), "r") as f:
    requirements = f.readlines()

setup(
    name=project,
    version=version,
    description="Snark Hub",
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="Snark AI Inc.",
    author_email="support@snark.ai",
    url="https://github.com/snarkai/hub",
    packages=find_packages(),
    include_package_data=True,
    zip_safe=False,
    keywords="snark-hub",
    python_requires=">=3",
    install_requires=requirements,
    setup_requires=[],
    dependency_links=[],
    entry_points={
        "console_scripts": [
            "hub = hub.cli.command:cli",
            "hub-local = hub.cli.local:cli",
            "hub-dev = hub.cli.dev:cli",
        ]
    },
    tests_require=["pytest", "mock>=1.0.1"],
)



from typing import *
import os, sys, io, time, random, traceback, json

import numpy as np
import pickle as msgpack


from .base import Base

class Default(Base):
    def __init__(self):
        super().__init__()

    def encode(self, array: np.ndarray) -> bytes:
        info = {
            'shape': array.shape,
            'dtype': str(array.dtype),
            'data': array.tobytes(),
        }
        return msgpack.dumps(info)

    def decode(self, bytes: bytes) -> np.ndarray:
        info = msgpack.loads(bytes)
        return np.frombuffer(bytearray(info['data']), dtype=info['dtype'])\
                                .reshape(info['shape'])